==> react-atom-popover-3.14.0.tgz: package/lib/config.js <==
import { Children } from 'react';
import cx from 'classnames';
import loadable from '@loadable/component';
import { jsx as _jsx } from "react/jsx-runtime";
export var TRIGGERS = {
  CLICK: 'click',
  FOCUS: 'focus',
  HOVER: 'hover',
  LEGACY: 'legacy',
  MANUAL: 'manual'
};
export var BASE_CLASS = 'sui-AtomPopover';
export var CLASS_INNER = BASE_CLASS + "-inner";
export var PREFIX_PLACEMENT = BASE_CLASS + "-";
export var DEFAULT_OFFSET = 'auto,4px';
export var DEFAULT_TRIGGER = TRIGGERS.LEGACY;
export var DEFAULT_DELAY = 0;

// https://github.com/reactstrap/reactstrap/blob/8.9.0/src/Popover.js
export var Popover = loadable(function () {
  return import('reactstrap/lib/Popover');
}, {
  ssr: true
});
export var PLACEMENTS = {
  AUTO: 'auto',
  AUTO_START: 'auto-start',
  AUTO_END: 'auto-end',
  TOP: 'top',
  TOP_START: 'top-start',
  TOP_END: 'top-end',
  RIGHT: 'right',
  RIGHT_START: 'right-start',
  RIGHT_END: 'right-end',
  BOTTOM: 'bottom',
  BOTTOM_START: 'bottom-start',
  BOTTOM_END: 'bottom-end',
  LEFT: 'left',
  LEFT_START: 'left-start',
  LEFT_END: 'left-end'
};
export var TYPES = {};
export var getClassName = function getClassName(_ref) {
  var _cx;
  var defaultClass = _ref.defaultClass,
    type = _ref.type;
  return cx(defaultClass, (_cx = {}, _cx[defaultClass + "--type-" + type] = Boolean(type), _cx));
};
export var getChildrenAsReactNode = function getChildrenAsReactNode(element) {
  return typeof children === 'string' ? [/*#__PURE__*/_jsx("span", {
    children: element
  }, 1)] : Children.only(element);
};

==> react-atom-popover-3.17.0.tgz: package/lib/config.js <==
import { Children } from 'react';
import cx from 'classnames';
import loadable from '@loadable/component';
import { jsx as _jsx } from "react/jsx-runtime";
export var TRIGGERS = {
  CLICK: 'click',
  FOCUS: 'focus',
  HOVER: 'hover',
  LEGACY: 'legacy',
  MANUAL: 'manual'
};
export var BASE_CLASS = 'sui-AtomPopover';
export var CLASS_INNER = BASE_CLASS + "-inner";
export var PREFIX_PLACEMENT = BASE_CLASS + "-";
export var DEFAULT_OFFSET = 'auto,4px';
export var DEFAULT_TRIGGER = TRIGGERS.LEGACY;
export var DEFAULT_DELAY = 0;

// https://github.com/reactstrap/reactstrap/blob/8.9.0/src/Popover.js
export var Popover = loadable(function () {
  return import('reactstrap/lib/Popover');
}, {
  ssr: true
});
export var PLACEMENTS = {
  AUTO: 'auto',
  AUTO_START: 'auto-start',
  AUTO_END: 'auto-end',
  TOP: 'top',
  TOP_START: 'top-start',
  TOP_END: 'top-end',
  RIGHT: 'right',
  RIGHT_START: 'right-start',
  RIGHT_END: 'right-end',
  BOTTOM: 'bottom',
  BOTTOM_START: 'bottom-start',
  BOTTOM_END: 'bottom-end',
  LEFT: 'left',
  LEFT_START: 'left-start',
  LEFT_END: 'left-end'
};
export var TYPES = {};
export var getClassName = function getClassName(_ref) {
  var _cx;
  var defaultClass = _ref.defaultClass,
    type = _ref.type;
  return cx(defaultClass, (_cx = {}, _cx[defaultClass + "--type-" + type] = Boolean(type), _cx));
};
export var getChildrenAsReactNode = function getChildrenAsReactNode(element) {
  return typeof element === 'string' ? /*#__PURE__*/_jsx("span", {
    children: element
  }, 1) : Children.only(element);
};
